==> eam-wshub-proxyclient-11.6-1-sources.jar: net/datastream/schemas/mp_entities/equipmentgeneration_001/EquipmentGeneration.java <==

package net.datastream.schemas.mp_entities.equipmentgeneration_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.EQUIPMENTGENERATIONID_Type;
import net.datastream.schemas.mp_fields.USERID_Type;
import org.openapplications.oagis_segments.DATETIME;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}EQUIPMENTGENERATIONID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PROCESSED" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ACTIVE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}AWAITINGPURCHASE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PROCESSERROR" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PROCESSRUNNING" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}LASTUPDATEDDATE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CREATEDDATE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CREATEDBY" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}UPDATEDBY" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DATEUPDATED" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_entities/EquipmentGeneration_001}EquipmentDetails"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_entities/EquipmentGeneration_001}PMScheduleandMaintenancePatternDetails" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_entities/EquipmentGeneration_001}CommissioningWorkOrderDetails" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_entities/EquipmentGeneration_001}CreateEquipmentStructure" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_entities/EquipmentGeneration_001}CopyData" minOccurs="0"/>
 *       &lt;/sequence>
 *       &lt;attribute name="recordid" type="{http://www.w3.org/2001/XMLSchema}long" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "equipmentgenerationid",
    "processed",
    "active",
    "awaitingpurchase",
    "processerror",
    "processrunning",
    "lastupdateddate",
    "createddate",
    "createdby",
    "updatedby",
    "dateupdated",
    "equipmentDetails",
    "pmScheduleandMaintenancePatternDetails",
    "commissioningWorkOrderDetails",
    "createEquipmentStructure",
    "copyData"
})
@XmlRootElement(name = "EquipmentGeneration")
public class EquipmentGeneration {

    @XmlElement(name = "EQUIPMENTGENERATIONID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected EQUIPMENTGENERATIONID_Type equipmentgenerationid;
    @XmlElement(name = "PROCESSED", namespace = "http://schemas.datastream.net/MP_fields", defaultValue = "false")
    protected String processed;
    @XmlElement(name = "ACTIVE", namespace = "http://schemas.datastream.net/MP_fields", defaultValue = "+")
    protected String active;
    @XmlElement(name = "AWAITINGPURCHASE", namespace = "http://schemas.datastream.net/MP_fields", defaultValue = "false")
    protected String awaitingpurchase;
    @XmlElement(name = "PROCESSERROR", namespace = "http://schemas.datastream.net/MP_fields", defaultValue = "false")
    protected String processerror;
    @XmlElement(name = "PROCESSRUNNING", namespace = "http://schemas.datastream.net/MP_fields", defaultValue = "false")
    protected String processrunning;
    @XmlElement(name = "LASTUPDATEDDATE", namespace = "http://schemas.datastream.net/MP_fields")
    protected DATETIME lastupdateddate;
    @XmlElement(name = "CREATEDDATE", namespace = "http://schemas.datastream.net/MP_fields")
    protected DATETIME createddate;
    @XmlElement(name = "CREATEDBY", namespace = "http://schemas.datastream.net/MP_fields")
    protected USERID_Type createdby;
    @XmlElement(name = "UPDATEDBY", namespace = "http://schemas.datastream.net/MP_fields")
    protected USERID_Type updatedby;
    @XmlElement(name = "DATEUPDATED", namespace = "http://schemas.datastream.net/MP_fields")
    protected DATETIME dateupdated;
    @XmlElement(name = "EquipmentDetails", required = true)
    protected EquipmentDetails equipmentDetails;
    @XmlElement(name = "PMScheduleandMaintenancePatternDetails")
    protected PMScheduleandMaintenancePatternDetails pmScheduleandMaintenancePatternDetails;
    @XmlElement(name = "CommissioningWorkOrderDetails")
    protected CommissioningWorkOrderDetails commissioningWorkOrderDetails;
    @XmlElement(name = "CreateEquipmentStructure")
    protected CreateEquipmentStructure createEquipmentStructure;
    @XmlElement(name = "CopyData")
    protected CopyData copyData;
    @XmlAttribute(name = "recordid")
    protected Long recordid;

    /**
     * Obtient la valeur de la propriété equipmentgenerationid.
     * 
     * @return
     *     possible object is
     *     {@link EQUIPMENTGENERATIONID_Type }
     *     
     */
    public EQUIPMENTGENERATIONID_Type getEQUIPMENTGENERATIONID() {
        return equipmentgenerationid;
    }

    /**
     * Définit la valeur de la propriété equipmentgenerationid.
     * 
     * @param value
     *     allowed object is
     *     {@link EQUIPMENTGENERATIONID_Type }
     *     
     */
    public void setEQUIPMENTGENERATIONID(EQUIPMENTGENERATIONID_Type value) {
        this.equipmentgenerationid = value;
    }

    /**
     * Obtient la valeur de la propriété processed.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPROCESSED() {
        return processed;
    }

    /**
     * Définit la valeur de la propriété processed.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPROCESSED(String value) {
        this.processed = value;
    }

    /**
     * Obtient la valeur de la propriété active.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getACTIVE() {
        return active;
    }

    /**
     * Définit la valeur de la propriété active.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setACTIVE(String value) {
        this.active = value;
    }

    /**
     * Obtient la valeur de la propriété awaitingpurchase.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getAWAITINGPURCHASE() {
        return awaitingpurchase;
    }

    /**
     * Définit la valeur de la propriété awaitingpurchase.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setAWAITINGPURCHASE(String value) {
        this.awaitingpurchase = value;
    }

    /**
     * Obtient la valeur de la propriété processerror.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPROCESSERROR() {
        return processerror;
    }

    /**
     * Définit la valeur de la propriété processerror.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPROCESSERROR(String value) {
        this.processerror = value;
    }

    /**
     * Obtient la valeur de la propriété processrunning.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPROCESSRUNNING() {
        return processrunning;
    }

    /**
     * Définit la valeur de la propriété processrunning.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPROCESSRUNNING(String value) {
        this.processrunning = value;
    }

    /**
     * Obtient la valeur de la propriété lastupdateddate.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getLASTUPDATEDDATE() {
        return lastupdateddate;
    }

    /**
     * Définit la valeur de la propriété lastupdateddate.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setLASTUPDATEDDATE(DATETIME value) {
        this.lastupdateddate = value;
    }

    /**
     * Obtient la valeur de la propriété createddate.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getCREATEDDATE() {
        return createddate;
    }

    /**
     * Définit la valeur de la propriété createddate.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setCREATEDDATE(DATETIME value) {
        this.createddate = value;
    }

    /**
     * Obtient la valeur de la propriété createdby.
     * 
     * @return
     *     possible object is
     *     {@link USERID_Type }
     *     
     */
    public USERID_Type getCREATEDBY() {
        return createdby;
    }

    /**
     * Définit la valeur de la propriété createdby.
     * 
     * @param value
     *     allowed object is
     *     {@link USERID_Type }
     *     
     */
    public void setCREATEDBY(USERID_Type value) {
        this.createdby = value;
    }

    /**
     * Obtient la valeur de la propriété updatedby.
     * 
     * @return
     *     possible object is
     *     {@link USERID_Type }
     *     
     */
    public USERID_Type getUPDATEDBY() {
        return updatedby;
    }

    /**
     * Définit la valeur de la propriété updatedby.
     * 
     * @param value
     *     allowed object is
     *     {@link USERID_Type }
     *     
     */
    public void setUPDATEDBY(USERID_Type value) {
        this.updatedby = value;
    }

    /**
     * Obtient la valeur de la propriété dateupdated.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getDATEUPDATED() {
        return dateupdated;
    }

    /**
     * Définit la valeur de la propriété dateupdated.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setDATEUPDATED(DATETIME value) {
        this.dateupdated = value;
    }

    /**
     * Obtient la valeur de la propriété equipmentDetails.
     * 
     * @return
     *     possible object is
     *     {@link EquipmentDetails }
     *     
     */
    public EquipmentDetails getEquipmentDetails() {
        return equipmentDetails;
    }

    /**
     * Définit la valeur de la propriété equipmentDetails.
     * 
     * @param value
     *     allowed object is
     *     {@link EquipmentDetails }
     *     
     */
    public void setEquipmentDetails(EquipmentDetails value) {
        this.equipmentDetails = value;
    }

    /**
     * Obtient la valeur de la propriété pmScheduleandMaintenancePatternDetails.
     * 
     * @return
     *     possible object is
     *     {@link PMScheduleandMaintenancePatternDetails }
     *     
     */
    public PMScheduleandMaintenancePatternDetails getPMScheduleandMaintenancePatternDetails() {
        return pmScheduleandMaintenancePatternDetails;
    }

    /**
     * Définit la valeur de la propriété pmScheduleandMaintenancePatternDetails.
     * 
     * @param value
     *     allowed object is
     *     {@link PMScheduleandMaintenancePatternDetails }
     *     
     */
    public void setPMScheduleandMaintenancePatternDetails(PMScheduleandMaintenancePatternDetails value) {
        this.pmScheduleandMaintenancePatternDetails = value;
    }

    /**
     * Obtient la valeur de la propriété commissioningWorkOrderDetails.
     * 
     * @return
     *     possible object is
     *     {@link CommissioningWorkOrderDetails }
     *     
     */
    public CommissioningWorkOrderDetails getCommissioningWorkOrderDetails() {
        return commissioningWorkOrderDetails;
    }

    /**
     * Définit la valeur de la propriété commissioningWorkOrderDetails.
     * 
     * @param value
     *     allowed object is
     *     {@link CommissioningWorkOrderDetails }
     *     
     */
    public void setCommissioningWorkOrderDetails(CommissioningWorkOrderDetails value) {
        this.commissioningWorkOrderDetails = value;
    }

    /**
     * Obtient la valeur de la propriété createEquipmentStructure.
     * 
     * @return
     *     possible object is
     *     {@link CreateEquipmentStructure }
     *     
     */
    public CreateEquipmentStructure getCreateEquipmentStructure() {
        return createEquipmentStructure;
    }

    /**
     * Définit la valeur de la propriété createEquipmentStructure.
     * 
     * @param value
     *     allowed object is
     *     {@link CreateEquipmentStructure }
     *     
     */
    public void setCreateEquipmentStructure(CreateEquipmentStructure value) {
        this.createEquipmentStructure = value;
    }

    /**
     * Obtient la valeur de la propriété copyData.
     * 
     * @return
     *     possible object is
     *     {@link CopyData }
     *     
     */
    public CopyData getCopyData() {
        return copyData;
    }

    /**
     * Définit la valeur de la propriété copyData.
     * 
     * @param value
     *     allowed object is
     *     {@link CopyData }
     *     
     */
    public void setCopyData(CopyData value) {
        this.copyData = value;
    }

    /**
     * Obtient la valeur de la propriété recordid.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getRecordid() {
        return recordid;
    }

    /**
     * Définit la valeur de la propriété recordid.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setRecordid(Long value) {
        this.recordid = value;
    }

}

==> eam-wshub-proxyclient-12.1-1-sources.jar: net/datastream/schemas/mp_entities/equipmentgeneration_001/EquipmentGeneration.java <==

package net.datastream.schemas.mp_entities.equipmentgeneration_001;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlAttribute;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlRootElement;
import jakarta.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.EQUIPMENTGENERATIONID_Type;
import net.datastream.schemas.mp_fields.USERID_Type;
import org.openapplications.oagis_segments.DATETIME;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>{@code
 * <complexType>
 *   <complexContent>
 *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       <sequence>
 *         <element ref="{http://schemas.datastream.net/MP_fields}EQUIPMENTGENERATIONID"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}PROCESSED" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}ACTIVE" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}AWAITINGPURCHASE" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}PROCESSERROR" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}PROCESSRUNNING" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}LASTUPDATEDDATE" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}CREATEDDATE" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}CREATEDBY" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}UPDATEDBY" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}DATEUPDATED" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_entities/EquipmentGeneration_001}EquipmentDetails"/>
 *         <element ref="{http://schemas.datastream.net/MP_entities/EquipmentGeneration_001}PMScheduleandMaintenancePatternDetails" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_entities/EquipmentGeneration_001}CommissioningWorkOrderDetails" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_entities/EquipmentGeneration_001}CreateEquipmentStructure" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_entities/EquipmentGeneration_001}CopyData" minOccurs="0"/>
 *       </sequence>
 *       <attribute name="recordid" type="{http://www.w3.org/2001/XMLSchema}long" />
 *     </restriction>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "equipmentgenerationid",
    "processed",
    "active",
    "awaitingpurchase",
    "processerror",
    "processrunning",
    "lastupdateddate",
    "createddate",
    "createdby",
    "updatedby",
    "dateupdated",
    "equipmentDetails",
    "pmScheduleandMaintenancePatternDetails",
    "commissioningWorkOrderDetails",
    "createEquipmentStructure",
    "copyData"
})
@XmlRootElement(name = "EquipmentGeneration")
public class EquipmentGeneration {

    @XmlElement(name = "EQUIPMENTGENERATIONID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected EQUIPMENTGENERATIONID_Type equipmentgenerationid;
    @XmlElement(name = "PROCESSED", namespace = "http://schemas.datastream.net/MP_fields", defaultValue = "false")
    protected String processed;
    @XmlElement(name = "ACTIVE", namespace = "http://schemas.datastream.net/MP_fields", defaultValue = "+")
    protected String active;
    @XmlElement(name = "AWAITINGPURCHASE", namespace = "http://schemas.datastream.net/MP_fields", defaultValue = "false")
    protected String awaitingpurchase;
    @XmlElement(name = "PROCESSERROR", namespace = "http://schemas.datastream.net/MP_fields", defaultValue = "false")
    protected String processerror;
    @XmlElement(name = "PROCESSRUNNING", namespace = "http://schemas.datastream.net/MP_fields", defaultValue = "false")
    protected String processrunning;
    @XmlElement(name = "LASTUPDATEDDATE", namespace = "http://schemas.datastream.net/MP_fields")
    protected DATETIME lastupdateddate;
    @XmlElement(name = "CREATEDDATE", namespace = "http://schemas.datastream.net/MP_fields")
    protected DATETIME createddate;
    @XmlElement(name = "CREATEDBY", namespace = "http://schemas.datastream.net/MP_fields")
    protected USERID_Type createdby;
    @XmlElement(name = "UPDATEDBY", namespace = "http://schemas.datastream.net/MP_fields")
    protected USERID_Type updatedby;
    @XmlElement(name = "DATEUPDATED", namespace = "http://schemas.datastream.net/MP_fields")
    protected DATETIME dateupdated;
    @XmlElement(name = "EquipmentDetails", required = true)
    protected EquipmentDetails equipmentDetails;
    @XmlElement(name = "PMScheduleandMaintenancePatternDetails")
    protected PMScheduleandMaintenancePatternDetails pmScheduleandMaintenancePatternDetails;
    @XmlElement(name = "CommissioningWorkOrderDetails")
    protected CommissioningWorkOrderDetails commissioningWorkOrderDetails;
    @XmlElement(name = "CreateEquipmentStructure")
    protected CreateEquipmentStructure createEquipmentStructure;
    @XmlElement(name = "CopyData")
    protected CopyData copyData;
    @XmlAttribute(name = "recordid")
    protected Long recordid;

    /**
     * Gets the value of the equipmentgenerationid property.
     * 
     * @return
     *     possible object is
     *     {@link EQUIPMENTGENERATIONID_Type }
     *     
     */
    public EQUIPMENTGENERATIONID_Type getEQUIPMENTGENERATIONID() {
        return equipmentgenerationid;
    }

    /**
     * Sets the value of the equipmentgenerationid property.
     * 
     * @param value
     *     allowed object is
     *     {@link EQUIPMENTGENERATIONID_Type }
     *     
     */
    public void setEQUIPMENTGENERATIONID(EQUIPMENTGENERATIONID_Type value) {
        this.equipmentgenerationid = value;
    }

    /**
     * Gets the value of the processed property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPROCESSED() {
        return processed;
    }

    /**
     * Sets the value of the processed property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPROCESSED(String value) {
        this.processed = value;
    }

    /**
     * Gets the value of the active property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getACTIVE() {
        return active;
    }

    /**
     * Sets the value of the active property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setACTIVE(String value) {
        this.active = value;
    }

    /**
     * Gets the value of the awaitingpurchase property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getAWAITINGPURCHASE() {
        return awaitingpurchase;
    }

    /**
     * Sets the value of the awaitingpurchase property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setAWAITINGPURCHASE(String value) {
        this.awaitingpurchase = value;
    }

    /**
     * Gets the value of the processerror property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPROCESSERROR() {
        return processerror;
    }

    /**
     * Sets the value of the processerror property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPROCESSERROR(String value) {
        this.processerror = value;
    }

    /**
     * Gets the value of the processrunning property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPROCESSRUNNING() {
        return processrunning;
    }

    /**
     * Sets the value of the processrunning property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPROCESSRUNNING(String value) {
        this.processrunning = value;
    }

    /**
     * Gets the value of the lastupdateddate property.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getLASTUPDATEDDATE() {
        return lastupdateddate;
    }

    /**
     * Sets the value of the lastupdateddate property.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setLASTUPDATEDDATE(DATETIME value) {
        this.lastupdateddate = value;
    }

    /**
     * Gets the value of the createddate property.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getCREATEDDATE() {
        return createddate;
    }

    /**
     * Sets the value of the createddate property.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setCREATEDDATE(DATETIME value) {
        this.createddate = value;
    }

    /**
     * Gets the value of the createdby property.
     * 
     * @return
     *     possible object is
     *     {@link USERID_Type }
     *     
     */
    public USERID_Type getCREATEDBY() {
        return createdby;
    }

    /**
     * Sets the value of the createdby property.
     * 
     * @param value
     *     allowed object is
     *     {@link USERID_Type }
     *     
     */
    public void setCREATEDBY(USERID_Type value) {
        this.createdby = value;
    }

    /**
     * Gets the value of the updatedby property.
     * 
     * @return
     *     possible object is
     *     {@link USERID_Type }
     *     
     */
    public USERID_Type getUPDATEDBY() {
        return updatedby;
    }

    /**
     * Sets the value of the updatedby property.
     * 
     * @param value
     *     allowed object is
     *     {@link USERID_Type }
     *     
     */
    public void setUPDATEDBY(USERID_Type value) {
        this.updatedby = value;
    }

    /**
     * Gets the value of the dateupdated property.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getDATEUPDATED() {
        return dateupdated;
    }

    /**
     * Sets the value of the dateupdated property.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setDATEUPDATED(DATETIME value) {
        this.dateupdated = value;
    }

    /**
     * Gets the value of the equipmentDetails property.
     * 
     * @return
     *     possible object is
     *     {@link EquipmentDetails }
     *     
     */
    public EquipmentDetails getEquipmentDetails() {
        return equipmentDetails;
    }

    /**
     * Sets the value of the equipmentDetails property.
     * 
     * @param value
     *     allowed object is
     *     {@link EquipmentDetails }
     *     
     */
    public void setEquipmentDetails(EquipmentDetails value) {
        this.equipmentDetails = value;
    }

    /**
     * Gets the value of the pmScheduleandMaintenancePatternDetails property.
     * 
     * @return
     *     possible object is
     *     {@link PMScheduleandMaintenancePatternDetails }
     *     
     */
    public PMScheduleandMaintenancePatternDetails getPMScheduleandMaintenancePatternDetails() {
        return pmScheduleandMaintenancePatternDetails;
    }

    /**
     * Sets the value of the pmScheduleandMaintenancePatternDetails property.
     * 
     * @param value
     *     allowed object is
     *     {@link PMScheduleandMaintenancePatternDetails }
     *     
     */
    public void setPMScheduleandMaintenancePatternDetails(PMScheduleandMaintenancePatternDetails value) {
        this.pmScheduleandMaintenancePatternDetails = value;
    }

    /**
     * Gets the value of the commissioningWorkOrderDetails property.
     * 
     * @return
     *     possible object is
     *     {@link CommissioningWorkOrderDetails }
     *     
     */
    public CommissioningWorkOrderDetails getCommissioningWorkOrderDetails() {
        return commissioningWorkOrderDetails;
    }

    /**
     * Sets the value of the commissioningWorkOrderDetails property.
     * 
     * @param value
     *     allowed object is
     *     {@link CommissioningWorkOrderDetails }
     *     
     */
    public void setCommissioningWorkOrderDetails(CommissioningWorkOrderDetails value) {
        this.commissioningWorkOrderDetails = value;
    }

    /**
     * Gets the value of the createEquipmentStructure property.
     * 
     * @return
     *     possible object is
     *     {@link CreateEquipmentStructure }
     *     
     */
    public CreateEquipmentStructure getCreateEquipmentStructure() {
        return createEquipmentStructure;
    }

    /**
     * Sets the value of the createEquipmentStructure property.
     * 
     * @param value
     *     allowed object is
     *     {@link CreateEquipmentStructure }
     *     
     */
    public void setCreateEquipmentStructure(CreateEquipmentStructure value) {
        this.createEquipmentStructure = value;
    }

    /**
     * Gets the value of the copyData property.
     * 
     * @return
     *     possible object is
     *     {@link CopyData }
     *     
     */
    public CopyData getCopyData() {
        return copyData;
    }

    /**
     * Sets the value of the copyData property.
     * 
     * @param value
     *     allowed object is
     *     {@link CopyData }
     *     
     */
    public void setCopyData(CopyData value) {
        this.copyData = value;
    }

    /**
     * Gets the value of the recordid property.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getRecordid() {
        return recordid;
    }

    /**
     * Sets the value of the recordid property.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setRecordid(Long value) {
        this.recordid = value;
    }

}
